@@ -17,31 +17,47 @@ end
 
 def handle_request( cgi, session)
 
-  etc_dir = ENV['APRS4R_ETC'] || "/etc/aprs4r"
-  @@logger.debug( "etc_dir: #{etc_dir}")
+  dir = cgi['dir']
 
-  file = cgi['file']
+  if !File.directory?( dir) 
+    output = "Content-Type: text/plain"
+    output += "\n\n"
+    output += "parameter dir (#{dir}) is no directory\n"
+    output += "\n"
+  end
 
-  config_file = nil
-  config_file = File.basename( file) if file
-  @@logger.debug( "config_file: #{config_file}")
+
+  name = cgi['file']
+  name = File.basename( name) if name
+
+  file = dir + "/" + name
+
+  if !File.file?( file)
+    output = "Content-Type: text/plain"
+    output += "\n\n"
+    output += "parameter file (#{file}) is no file\n"
+    output += "\n"
+  end
 
   output = "" 
-  if config_file 
-    output = "Content-Disposition: attachment; filename=#{config_file}"
+  if file 
+    output = "Content-Disposition: attachment; filename=#{name}"
     output += "\n\n"
 
     begin 
-      File.open( etc_dir + "/" + config_file).each { |line|
+      File.open( file).each { |line|
         output += line
       }
-    rescue Exception 
+    rescue Exception => ex
+      output = "Content-Type: text/plain"
+      output += "\n\n"
+      output += "Error: #{ex}\n"
     end
   else
     output = "Content-Type: text/plain"
     output += "\n\n"
 
-    output += "File #{config_file} not found..."
+    output += "File #{file} not found..."
   end
 
   return output
